@@ -114,6 +114,10 @@ class Experiment:
             return False
 
     def print_status(self):
+        if not self.is_running():
+            print("### Experiment NOT running! ###\n")
+        else:
+            print("Running...")
         print_status(self)
 
 
